# name: midnight commander
# desc: default parameter manifest for midnight commander module
# auth: Kai Burghardt <wiz at KaiBurghardt.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent fdm=marker:

function midnight_commander::data() {
	# all the logics
	$etc_mc_skins_path              = $::facts['os']['family'] ? {
		'FreeBSD'                     => '/usr/local/etc/mc/skins/',
		default                       => '/etc/mc/skins/',
	}
	$etc_mc_skins_owner             = 'root'
	$etc_mc_skins_group             = $::facts['os']['family'] ? {
		'FreeBSD'                     => 'wheel',
		default                       => 'root',
	}
	$mc_ini_path                    = $::facts['os']['family'] ? {
		'FreeBSD'                     => '/usr/local/etc/mc/mc.ini',
		default                       => '/etc/mc/mc.ini',
	}
	$mc_ini_group                   = $::facts['os']['family'] ? {
		'FreeBSD'                     => 'wheel',
		default                       => 'root',
	}
	
	# parameters which can be expressed by a (non-branched) expression
	$params = {
		# package install
		'mc_package_name'               => 'mc',
		'latest_instead_of_present'     => false,
		# skins
		'etc_mc_skins_path'             => $etc_mc_skins_path,
		'etc_mc_skins_default_path'     => "${etc_mc_skins_path}default.ini",
		'etc_mc_skins_owner'            => $etc_mc_skins_owner,
		'etc_mc_skins_group'            => $etc_mc_skins_group,
		'etc_mc_skins_default_owner'    => $etc_mc_skins_owner,
		'etc_mc_skins_default_group'    => $etc_mc_skins_group,
		# mc.ini
		'distribute_global_mc_ini'      => true,
		'mc_ini_path'                   => $mc_ini_path,
		'mc_ini_mode'                   => '0644',
		'mc_ini_owner'                  => 'root',
		'mc_ini_group'                  => $mc_ini_group,
		'mc_ini_template'               => 'midnight_commander/mc_ini.erb',
		'mc_ini_auth'                   => 'Kai Burghardt <wiz at KaiBurghardt.de>',
	}
	
	# [['foo', 'bar'], ['key', 42]] to_hash() becomes {'foo' => 'bar', 'key' => 42}
	Hash($params.map | $key, $value | {
		["${module_name}::${key}", $value]
	})
}
# EOF
