# name: midnight commander
# desc: init manifest for midnight commander module
# auth: Kai Burghardt <wiz at KaiBurghardt.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent fdm=marker:

class midnight_commander (
	# package
	Pattern[/^.*$/]          $mc_package_name               = $midnight_commander::params::mc_package_name,
	Boolean                  $latest_instead_of_present     = $midnight_commander::params::latest_instead_of_present,
	# mc.ini
	Boolean                  $distribute_global_mc_ini      = $midnight_commander::params::distribute_global_mc_ini,
	Pattern[/^.+$/]          $mc_ini_path                   = $midnight_commander::params::mc_ini_path,
	Optional[Pattern[/^0[0-7]{3}$/]]
	                         $mc_ini_mode                   = $midnight_commander::params::mc_ini_mode,
	Optional[Pattern[/^.*$/]]
	                         $mc_ini_owner                  = $midnight_commander::params::mc_ini_owner,
	Optional[Pattern[/^.*$/]]
	                         $mc_ini_group                  = $midnight_commander::params::mc_ini_group,
	Pattern[/^.*$/]          $mc_ini_template               = $midnight_commander::params::mc_ini_template,
	Pattern[/^.*$/]          $mc_ini_auth                   = $midnight_commander::params::mc_ini_auth,
	# skin
	Optional[Pattern[/^.*$/]]
	                         $etc_mc_skins_default_symlink  = $midnight_commander::params::etc_mc_skins_default_symlink,
	Pattern[/^.*$/]          $etc_mc_skins_path             = $midnight_commander::params::etc_mc_skins_path,
	Optional[Pattern[/^0[0-7]{3}$/]]
	                         $etc_mc_skins_mode             = $midnight_commander::params::etc_mc_skins_mode,
	Optional[Pattern[/^.*$/]]
	                         $etc_mc_skins_owner            = $midnight_commander::params::etc_mc_skins_owner,
	Optional[Pattern[/^.*$/]]
	                         $etc_mc_skins_group            = $midnight_commander::params::etc_mc_skins_group,
	Pattern[/^.+$/]          $etc_mc_skins_default_path     = $midnight_commander::params::etc_mc_skins_default_path,
	Optional[Pattern[/^.*$/]]
	                         $etc_mc_skins_default_owner    = $midnight_commander::params::etc_mc_skins_default_owner,
	Optional[Pattern[/^.*$/]]
	                         $etc_mc_skins_default_group    = $midnight_commander::params::etc_mc_skins_default_group,
	
	# O P T I O N S :   C O N F I G U R A T I O N
	# file operations
	Optional[Variant[Default, Boolean]]
	                         $mc_verbose                    = undef,
	Optional[Boolean]        $mc_file_op_compute_totals     = undef,
	Optional[Boolean]        $mc_classic_progressbar        = undef,
	Optional[Boolean]        $mc_auto_fill_mkdir_name       = undef,
	Optional[Boolean]        $mc_preallocate_space          = undef,
	# esc key mode
	Optional[Boolean]        $mc_old_esc_mode               = undef,
	Optional[Integer]        $mc_old_esc_mode_timeout       = undef,
	# pause after run
	Optional[Enum['never', 'on_dumb_terminals', 'always']]
	                         $mc_pause_after_run            = undef,
	# other options
	Optional[Boolean]        $mc_use_internal_edit          = undef,
	Optional[Boolean]        $mc_use_internal_view          = undef,
	Optional[Boolean]        $mc_editor_ask_filename_b_edit = undef,
	Optional[Boolean]        $mc_auto_menu                  = undef,
	Optional[Boolean]        $mc_drop_menus                 = undef,
	Optional[Boolean]        $mc_shell_patterns             = undef,
	Optional[Boolean]        $mc_show_all_if_ambiguous      = undef,
	Optional[Boolean]        $mc_nice_rotating_dash         = undef,
	Optional[Boolean]        $mc_cd_symlinks                = undef,
	Optional[Boolean]        $mc_safe_delete                = undef,
	Optional[Boolean]        $mc_auto_save_setup            = undef,
	# O P T I O N S :   C O N F I R M A T I O N
	Optional[Boolean]        $mc_confirm_delete             = undef,
	Optional[Boolean]        $mc_confirm_overwrite          = undef,
	Optional[Boolean]        $mc_confirm_execute            = undef,
	Optional[Boolean]        $mc_confirm_exit               = undef,
	Optional[Boolean]        $mc_confirm_dir_hotlist_del    = undef,
	Optional[Boolean]        $mc_confirm_history_cleanup    = undef,
	# O P T I O N S :   A P P E A R A N C E
	Optional[Pattern[/^.*$/]]
	                         $mc_skin                       = undef,
	# O P T I O N S :   D I S P L A Y   B I T S
	Optional[Boolean]        $mc_use_8th_bit_as_meta        = undef,
	# O P T I O N S :   V I R T U A L   F S
	# virtual file system setting
	Optional[Integer]        $mc_vfs_timeout                = undef,
	# ---
	Optional[Integer]        $mc_ftpfs_directory_timeout    = undef,
	Optional[Boolean]        $mc_ftpfs_always_use_proxy     = undef,
	Optional[Boolean]        $mc_use_netrc                  = undef,
	Optional[Boolean]        $mc_ftpfs_use_pasconex         = undef,
	Optional[Boolean]        $mc_ftpfs_use_pasconex_x_proxy = undef,
	# E D I T O R :   O P T I O N S :   G E N E R A L
	# wrap mode
	Optional[Boolean]        $mc_editor_option_auto_par_fmt = undef,
	Optional[Boolean]        $mc_editor_option_typewr_wrap  = undef,
	# tabulation
	Optional[Boolean]        $mc_editor_fake_half_tabs      = undef,
	Optional[Boolean]        $mc_editor_backspc_throu_tabs  = undef,
	Optional[Boolean]        $mc_editor_fill_tabs_w_spaces  = undef,
	Optional[Integer]        $mc_editor_tab_spacing         = undef,
	# other options
	Optional[Boolean]        $mc_editor_return_d_auto_indnt = undef,
	Optional[Boolean]        $mc_editor_edit_confirm_save   = undef,
	Optional[Boolean]        $mc_editor_option_sav_position = undef,
	Optional[Boolean]        $mc_editor_visible_spaces      = undef,
	Optional[Boolean]        $mc_editor_visible_tabs        = undef,
	Optional[Boolean]        $mc_editor_syntax_highlighting = undef,
	Optional[Boolean]        $mc_editor_cursr_after_ins_blk = undef,
	Optional[Boolean]        $mc_editor_persistnt_selexions = undef,
	Optional[Boolean]        $mc_editor_cursor_beyond_eol   = undef,
	Optional[Boolean]        $mc_editor_group_undo          = undef,
	Optional[Integer]        $mc_editor_word_wrap_ln_length = undef,
	# E D I T O R :   O P T I O N S :   S A V E   M O D E
	# edit save mode
	Optional[Enum['quick_save', 'safe_save', 'do_backups_with_extension']]
	                         $mc_editor_option_sav_mode     = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_editor_backup_extension    = undef,
	# ---
	Optional[Boolean]        $mc_editor_check_new_line      = undef,
	#
	# other documented options (cmp. mc(1), mcedit(1))
	Optional[Boolean]        $mc_editor_line_state          = undef,
	Optional[Array[Pattern[/^.$/], 1]]
	                         $mc_editor_stop_format_chars   = undef,
	Optional[Boolean]        $mc_editor_wrdcompl_coll_ent_f = undef,
	# other undocumented options
	Optional[Boolean]        $mc_editor_simple_statusbar    = undef,
	Optional[Boolean]        $mc_editor_show_right_margin   = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_editor_filesize_threshold  = undef,
	# V I E W E R
	Optional[Pattern[/^.*$/]]
	                         $mc_mcview_eof                 = undef,
	Optional[Boolean]        $mc_mcview_remember_file_pos   = undef,
	# S P E C I A L   S E T T I N G S
	Optional[Integer]        $mc_max_dirt_limit             = undef,
	Optional[Boolean]        $mc_mouse_move_pages_viewer    = undef,
	Optional[Boolean]        $mc_only_leading_plus_minus    = undef,
	Optional[Boolean]        $mc_show_output_starts_shell   = undef,
	Optional[Boolean]        $mc_use_file_to_guess_type     = undef,
	Optional[Boolean]        $mc_xtree_mode                 = undef,
	Optional[Integer]        $mc_fish_directory_timeout     = undef,
	# undocumented stuff: mouse interaction
	Optional[Boolean]        $mc_mouse_close_dialog         = undef,
	Optional[Integer]        $mc_mouse_repeat_rate          = undef,
	Optional[Integer]        $mc_double_click_speed         = undef,
	# other FTP stuff
	Optional[Integer]        $mc_ftpfs_retry_seconds        = undef,
	Optional[Boolean]        $mc_ftpfs_use_unix_lst_options = undef,
	Optional[Boolean]        $mc_ftpfs_first_cd_then_ls     = undef,
	Optional[Boolean]        $mc_ignore_ftp_chattr_errors   = undef,
	# misc
	Optional[Pattern[/^.*$/]]
	                         $mc_keymap                     = undef,
	Optional[Boolean]        $mc_alternate_plus_minus       = undef,
	Optional[Boolean]        $mc_confirm_view_dir           = undef,
	Optional[Boolean]        $mc_clear_before_exec          = undef,
	Optional[Boolean]        $mc_wrap_mode                  = undef,
	Optional[Boolean]        $mc_fast_refresh               = undef,
	Optional[Integer]        $mc_num_history_items_recorded = undef,
	Optional[Integer]        $mc_select_flags               = undef,
	Optional[Boolean]        $mc_copymove_persistent_attr   = undef,
	# legacy?
	Optional[Boolean]        $mc_horizontal_split           = undef,
	Optional[Boolean]        $mc_kilobyte_si                = undef,
	Optional[Boolean]        $mc_mix_all_files              = undef,
	Optional[Boolean]        $mc_show_backups               = undef,
	Optional[Boolean]        $mc_show_dot_files             = undef,
	Optional[Boolean]        $mc_fast_reload                = undef,
	Optional[Boolean]        $mc_fast_reload_msg_shown      = undef,
	Optional[Boolean]        $mc_mark_moves_down            = undef,
	Optional[Boolean]        $mc_reverse_files_only         = undef,
	Optional[Boolean]        $mc_auto_save_setup_panels     = undef,
	Optional[Boolean]        $mc_navigate_with_arrows       = undef,
	Optional[Boolean]        $mc_mouse_moves_pages          = undef,
	Optional[Boolean]        $mc_mouse_moves_pages_viewer   = undef,
	Optional[Boolean]        $mc_panel_scroll_pages         = undef,
	Optional[Boolean]        $mc_torben_fj_mode             = undef,
	
	# O P T I O N S :   L A Y O U T
	# panel split
	Optional[Boolean]        $mc_layout_horizontal_split    = undef,
	Optional[Boolean]        $mc_layout_equal_split         = undef,
	Optional[Integer]        $mc_layout_first_panel_size    = undef,
	Optional[Boolean]        $mc_layout_horizontal_equal    = undef,
	Optional[Integer]        $mc_layout_top_panel_size      = undef,
	Optional[Boolean]        $mc_layout_vertical_equal      = undef,
	Optional[Integer]        $mc_layout_left_panel_size     = undef,
	# console output
	Optional[Integer]        $mc_layout_output_lines        = undef,
	# other options
	Optional[Boolean]        $mc_layout_menubar_visible     = undef,
	Optional[Boolean]        $mc_layout_command_prompt      = undef,
	Optional[Boolean]        $mc_layout_keybar_visible      = undef,
	Optional[Boolean]        $mc_layout_message_visible     = undef,
	Optional[Boolean]        $mc_layout_xterm_title         = undef,
	Optional[Boolean]        $mc_layout_free_space          = undef,
	# options not found in the TUI
	Optional[Boolean]        $mc_layout_show_mini_info      = undef,
	Optional[Boolean]        $mc_layout_filetype_mode       = undef,
	Optional[Boolean]        $mc_layout_permission_mode     = undef,
	
	Optional[Array[Pattern[/^.*$/], 1]]
	                         $mc_colors_color_terminals     = undef,
	#Optional[Pattern[/^.*$/]]
	#                         $mc_colors_base_color          = undef,
	#Optional[Pattern[/^.*$/]]
	#                         $mc_colors_screen_linux        = undef,
	#Optional[Pattern[/^.*$/]]
	#                         $mc_colors_screen_mlterm       = undef,
	#Optional[Pattern[/^.*$/]]
	#                         $mc_colors_xterm               = undef,
	#Optional[Pattern[/^.*$/]]
	#                         $mc_colors_mlterm              = undef,
	
	# O P T I O N S :   P A N E L   O P T I O N S
	# main options
	Optional[Boolean]        $mc_panels_show_mini_info      = undef,
	Optional[Boolean]        $mc_panels_kilobyte_si         = undef,
	Optional[Boolean]        $mc_panels_mix_all_files       = undef,
	Optional[Boolean]        $mc_panels_show_backups        = undef,
	Optional[Boolean]        $mc_panels_show_dot_files      = undef,
	Optional[Boolean]        $mc_panels_fast_reload         = undef,
	Optional[Boolean]        $mc_panels_fast_relod_msg_shwn = undef,
	Optional[Boolean]        $mc_panels_mark_moves_down     = undef,
	Optional[Boolean]        $mc_panels_reverse_files_only  = undef,
	Optional[Boolean]        $mc_panels_simple_swap         = undef,
	Optional[Boolean]        $mc_panels_auto_sav_setup_pnls = undef,
	# navigation
	Optional[Boolean]        $mc_panels_navigate_w_arrows   = undef,
	Optional[Boolean]        $mc_panels_panel_scroll_pages  = undef,
	Optional[Boolean]        $mc_panels_mouse_move_pages    = undef,
	Optional[Boolean]        $mc_panels_torben_fj_mode      = undef,
	# file highlight
	Optional[Boolean]        $mc_panels_filetype_mode       = undef,
	Optional[Boolean]        $mc_panels_permission_mode     = undef,
	# quick search
	Optional[Enum['case_insensitive', 'case_sensitive', 'use_panel_sort_mode']]
	                         $mc_panels_quick_search_mode   = undef,
	
	# O P T I O N S :   D I S P L A Y   B I T S
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_display_codepage      = undef,
	# O P T I O N S :   V I R T U A L   F S
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_ftpfs_password        = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_ftp_proxy_host        = undef,
	# 
	# not accessible via TUI but documented in the man page
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_timeformat_recent     = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_timeformat_old        = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_clipboard_store       = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_clipboard_paste       = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_autodetect_codeset    = undef,
	# no reference found except they appeared in my .ini
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_spell_language        = undef,
	Optional[Pattern[/^.*$/]]
	                         $mc_misc_source_codepage       = undef,
	#Optional[Array[Pattern[/^[^[:blank:]\n]*[^[:blank:]\n\/]$/], 1]]
	#                         $mc_misc_find_ignore_dirs      = undef,
) inherits midnight_commander::params {
	Class['midnight_commander::install'] -> Class['midnight_commander::config']
	contain 'midnight_commander::install'
	contain 'midnight_commander::config'
}
# EOF
