[//]: # ( name: readme markdown )
[//]: # ( desc: readme for midnight_commander puppet module )
[//]: # ( auth: Kai Burghardt <wiz at KaiBurghardt.de> )
[//]: # ( edit: this file should be saved in enc=utf8 )
[//]: # ( viim: modeline at bottom )
[//]: # ( note: there are non-breaking spaces [like this one ' '] )
[//]: # (       in vim you can :set list lcs=eol:⏎,tab:↹⋯,nbsp:⍽  )

# midnight\_commander

#### Table of Contents

1. [Overview](#overview)
2. [Module Description – What the module does and why it is useful](#module-description)
3. [Setup – The basics of getting started with midnight\_commander](#setup)
	* [What midnight\_commander affects](#what-midnight_commander-affects)
	* [Setup requirements](#setup-requirements)
	* [Beginning with midnight\_commander](#beginning-with-midnight_commander)
4. [Usage – Configuration options and additional functionality](#usage)
5. [Reference – An under-the-hood peek at what the module is doing and how](#reference)
6. [Limitations – OS compatibility, etc.](#limitations)
7. [Development – Guide for contributing to the module](#development)
8. [Index](#index)


## Overview

This module installs and globally configures the GNU midnight commander.


## Module description

This module installs GNU midnight commander (`mc`) –
a free text-user-interface file manager.


## Setup

### What midnight\_commander affects

* installs `mc` package
* Optionally: overwrite `/etc/mc/mc.ini`
  ([`distribute_global_mc_ini`](#distribute_global_mc_ini))
* Optionally: set symlink target for `/etc/mc/skins/default.ini`
  and create `/etc/mc/skins/` for that


### Setup requirements

This module requires the future parser
([for PP 3.8 users](https://docs.puppet.com/puppet/3.8/reference/experiments_future.html)).


### Beginning with midnight\_commander

Just installing `mc` and doing nothing else:

	class my_custom_software_bundle_wrapper_class {
		class { 'midnight_commander':
			distribute_global_mc_ini     => false,
		}
	}


## Usage

This is how I set up my mc:

	class tuifilemanager {
		class { 'midnight_commander':
			mc_verbose                    => true,
			mc_use_internal_edit          => false,
			mc_use_internal_view          => false,
			
			mc_confirm_exit               => false,
			mc_skin                       => 'gotar',
			
			mc_kilobyte_si                => false,
			mc_show_backups               => true,
			mc_show_dot_files             => true,
			
			mc_layout_menubar_visible     => false,
			mc_layout_keybar_visible      => false,
			mc_layout_message_visible     => false,
			mc_layout_xterm_title         => false,
			mc_layout_show_mini_info      => false,
		}
	}

Both examples are included in `examples/`.
(There's also an example containing
[all possible parameters](#parameters).)

The default `mc.ini` template is populated
with configuration values _you_ specified,
since all of them are `undef` by default.


## Reference

### Classes

* `midnight_commander`: holds the class parameter types
  and [`contain`](https://docs.puppet.com/puppet/latest/reference/function.html#contain)s
  the other classes
* `midnight_commander::params`: contains default values
  `midnight_commander` inherits from
  (a `data` function for
  [PP lookup](https://docs.puppet.com/puppet/latest/reference/lookup_quick_module.html)
  is already prepared)
* `midnight_commander::install`: installs the `mc` package
* `midnight_commander::config`: distributes the configuration files


### Parameters

The following incorporates help from `/usr/share/mc/help/mc.hlp`.
If I'm not wrong,
it is licensed under [GPL-3+](https://spdx.org/licenses/GPL-3.0+.html).

Platform independent defaults are printed _emphasized_.
Considered as such are only defaults,
which are very unlikely to ever change amongst platforms.
So even though [`mc_package_name`'s](#mc_package_name)
default value always is `mc` (by now),
I'd expect _some_ distribution out there does it differently.

The following parameters are sorted by topic –
related settings are next to each other.
See [§ index](#index) for an alphabetical list of all class parameters.


#### `mc_package_name`

* In case you need to overwrite the
  [name of the package](https://docs.puppet.com/puppet/latest/reference/types/package.html#package-attribute-name).
  The `package` resource is titled `midnight_commander`.
  The package is only managed,
  if the package name is of positive length.
  Usually the package is named `mc`.

* `mc_package_name ~= /^.*$/`


#### `latest_instead_of_present`

* `Package['midnight_commander']` is `present` by default.
   Set this parameter to `true`, to ensure it's `latest`.

* `latest_instead_of_present` ∊ {_`false`_, `true`}


#### `distribute_global_mc_ini`

* Whether to manage the file located at [`mc_ini_path`](#mc_ini_path).

* `distribute_global_mc_ini` ∊ {`false`, _`true`_}


#### `mc_ini_path`

* The path to the system-wide `mc.ini`.

* Unfortunately I did not find any (documented) place
  for a system-wide configuration file in `/etc/`
  (I did grep for `etc` in `mc(1)`).
  So we overwrote the file in `/usr/share/mc/`
  which has been around there for quite some time
  (older `mc` packages).
  In the meantime I did some trial'n'error
  and wrote something to `/etc/mc/mc.ini`.
  Apparantly configuration from `etc` gets considered
  and takes precedence.

* This string's gotta be of positive length.

* If you don't wanna write this file
  set [`distribute_global_mc_ini`](#distribute_global_mc_ini) to `false`.

* `mc_ini_path ~= /^.+$/`


#### `mc_ini_mode`

* Optionally enforce a mode of the `mc.ini` file.

* By default `0644` is enforced.

* `mc_ini_mode ~= /^0[0-7]{3}$/` + `mc_ini_mode` = `undef`


#### `mc_ini_owner`

* Optionally the owner of the `mc.ini`.

* Normally `root` becomes the owner.

* `mc_ini_owner ~= /^.*$/` + `mc_ini_owner` = `undef`


#### `mc_ini_group`

* Optionally enforce the group of `mc.ini`.

* This defaults to `wheel` on `FreeBSD`
  [osfamily](https://docs.puppet.com/facter/latest/core_facts.html#osfamily),
  `root` otherwise.

* `mc_ini_group ~= /^.*$/` + `mc_ini_group` = `undef`


#### `mc_ini_template`

* The global `mc.ini` is generated by
  [`template()`](https://docs.puppet.com/puppet/latest/reference/function.html#template).
  Change it to use another template.

* The default template fills only with configuration values,
  which _are_ present.
  As you start `mc(1)`
  all non-specified values are supplemented.
  `mc(1)` will then write a _complete_ `mc.ini`
  in the user's `~/.config/mc/ini`.

* `mc_ini_template ~= /^.*$/`


#### `mc_ini_auth`

* What to fill in as author in the default distributed template.

* This field says author,
  but at our site it's used as a general responsibility tag.
  The default is `'Kai Burghardt <wiz at KaiBurghardt.de>'`.

* `mc_ini_auth ~= /^.*$/`


#### `etc_mc_skins_default_symlink`

* Holds the target `/etc/mc/skins/default.ini` points to.

* It is ensured the `skins/` subdirectory exists in `/etc/mc/`
  prior creating the symbolic link.

* By default this parameter is `undef`ined,
  so nothing's touched.

* If you wanna get rid of the link itself
  (once it's already out there),
  assign a zero-length value.

* `etc_mc_skins_default_symlink ~= /^.*$/` +
  `etc_mc_skins_default_symlink` = _`undef`_


#### `etc_mc_skins_path`

* The path to the directory `/etc/mc/skins/`.

* (On `FreeBSD` it defaults to `/usr/local/etc/mc/skins/`)

* It is created before the `default.ini` symlink.
  It is created,
  if [`etc_mc_skins_default_symlink`](#etc_mc_skins_default_symlink)
  is an empty string, too.

* `etc_mc_skins_path ~= /^.*$/`


#### `etc_mc_skins_mode`

* Optionally the mode of `/etc/mc/skins/`.

* Normally `0755` is ensured.

* `etc_mc_skins_mode ~= /^0[0-7]{3}$/` + `etc_mc_skins_mode` = `undef`


#### `etc_mc_skins_owner`

* Optionally the owner of `/etc/mc/skins/`.

* That's `root` by default.

* `etc_mc_skins_owner ~= /^.*$/` + `etc_mc_skins_owner` = `undef`


#### `etc_mc_skins_group`

* Optionally enforce `/etc/mc/skins/` belongs a specific group.

* On `FreeBSD` the value is `wheel`, `root` anywhere else.

* `etc_mc_skins_group ~= /^.*$/` + `etc_mc_skins_group` = `undef`


#### `etc_mc_skins_default_path`

* The path of `/etc/mc/skins/default.ini`.

* It is set to [`etc_mc_skins_path`](#etc_mc_skins_path)
  appended with `'default.ini'`.

* The file mode is always set to `0777`.

* `etc_mc_skins_default_path ~= /^.+$/`


#### `etc_mc_skins_default_owner`

* Same as [`etc_mc_skins_owner`](#etc_mc_skins_owner).

* `etc_mc_skins_default_owner ~= /^.*$/` +
  `etc_mc_skins_default_owner` = `undef`


#### `etc_mc_skins_default_group`

* Same as [`etc_mc_skins_group`](#etc_mc_skins_group).

* `etc_mc_skins_default_group ~= /^.*$/` +
  `etc_mc_skins_default_group` = `undef`


#### `mc_verbose`

* This toggles whether the file copy, rename and delete operations are verbose
  (for example, display a dialog box for each operation).
  If you have a slow terminal, you may wish to disable the verbose operation.
  It is automatically turned off
  if the speed of your terminal is less than 9600 bit s⁻¹.

* `mc_verbose` ∊ {`false`, `true`, _`undef`_}


#### `mc_file_op_compute_totals`

* If this option is enabled,
  `mc(1)` computes
  total byte sizes and total number of files
  prior to any copy, rename and delete operations.
  This will provide you
  with a more accurate progress bar at the expense of some speed.
  This option has no effect, if verbose operation is disabled.

* `mc_file_op_compute_totals` ∊ {`false`, `true`, _`undef`_}


#### `mc_classic_progressbar`

* If this option is enabled,
  the progressbar of copy/move/delete operations
  is always grown from left to right.
  If disabled,
  the growing direction of progressbar
  follows to direction of copy/move/delete operation:
  from left panel to right one and vice versa.
  Enabled by default.

* `mc_classic_progressbar` ∊ {`false`, `true`, _`undef`_}


#### `mc_auto_fill_mkdir_name`

* When you press `F7` to create a new directory,
  the input line in popup dialog
  will be filled by name of current file or directory in active panel.
  Disabled by default.

* `mc_auto_fill_mkdir_name` ∊ {`false`, `true`, _`undef`_}


#### `mc_preallocate_space`

* Preallocate space for whole target file, if possible,
  before copy operation.
  Disabled by default.

* `mc_preallocate_space` ∊ {`false`, `true`, _`undef`_}


#### `mc_old_esc_mode`

* By default the Midnight Commander treats the `ESC` key as a key prefix.
  Therefore, you should press Esc code twice to exit a dialog.
  But there is possibility to use a single press of `ESC` key for that action.

* By default this option is disabled.
  If you'll enable it,
  the `ESC` key will act as a prefix key for set up time interval
  (see timeout option below),
  and if no extra keys have arrived,
  then the `ESC` key is interpreted as a cancel key (`ESC ESC`).

* `mc_old_esc_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_old_esc_mode_timeout`

* This options is used
  to setup the time interval (in microseconds) for single press of `ESC` key.
  By default, this interval is one second (1,000,000 μ″).
  Also the timeout can be set
  via `KEYBOARD_KEY_TIMEOUT_US` environment variable (also in microseconds),
  which has higher priority than the timeout option value.

* `mc_old_esc_mode_timeout` ∊ ℤ ∪ {_`undef`_}


#### `mc_pause_after_run`

* After executing your commands, the Midnight Commander can pause,
  so that you can examine the output of the command.
  There are three possible settings for this variable:
	
	* `'never'`:
	  Means that you do not want to see the output of your command.
	  If you are using the Linux or FreeBSD console or an `xterm(1)`,
	  you will be able to see the output of the command by typing `C-o`.
	
	* `'on_dumb_terminals'`:
	  You will get the pause message on terminals
	  that are not capable of showing the output of the last command executed
	  (any terminal that is not an xterm or the Linux console).
	
	* `'always'`:
	  The program will pause after executing all of your commands.

* `mc_pause_after_run` ∊ {`'never'`, `'on_dumb_terminals'`, `'always'`, _`undef`_}


#### `mc_use_internal_edit`

* If this option is enabled,
  the built-in file editor `mcedit(1)` is used to edit files.
  If the option is disabled,
  the editor specified in the `EDITOR` environment variable is used.
  If no editor is specified, `vi(1)` is used.
  See the section on the internal file editor.

* `mc_use_internal_edit` ∊ {`false`, `true`, _`undef`_}


#### `mc_use_internal_view`

* If this option is enabled,
  the built-in file viewer `mcview(1)` is used to edit files.
  If the option is disabled,
  the pager specified in the `PAGER` environment variable is used.
  If no pager is specified, the `view` command is used.

* `mc_use_internal_view` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_ask_filename_b_edit`

* Ask for a new file name before editing with `mcedit(1)`.

* `mc_editor_ask_filename_b_edit` ∊ {`false`, `true`, _`undef`_}


#### `mc_auto_menu`

* If this option is enabled,
  the user menu will be invoked at startup.
  Useful for building menus for non-unixers.

* `mc_auto_menu` ∊ {`false`, `true`, _`undef`_}


#### `mc_drop_menus`

* When this option is enabled,
  the pull down menus will be activated as soon as you press the `F9` key.
  Otherwise, you will only get the menu title,
  and you will have to activate the menu
  either with the arrow keys or with the hotkeys.
  It is recommended if you are using hotkeys.

* `mc_drop_menus` ∊ {`false`, `true`, _`undef`_}


#### `mc_shell_patterns`

* By default the select, unselect and filter commands
  will use shell-like regular expressions.
  The following conversions are performed to achieve this:
  `*` is replaced by `.*` (zero or more characters);
  the `?` is replaced by `.` (exactly one character)
  and `.` by the literal dot.
  If the option is disabled,
  then the regular expressions are the ones described in `ed(1)`.

* `mc_shell_patterns` ∊ {`false`, `true`, _`undef`_}


#### `mc_show_all_if_ambiguous`

* By default the Midnight Commander pops up all possible completions
  if the completion is ambiguous
  only when you press `Alt-Tab` for the second time.
  For the first time,
  it just completes as much as possible and beeps in the case of ambiguity.
  Enable this option
  if you want to see all possible completions
  even after pressing `Alt-Tab` the first time.

* `mc_show_all_if_ambiguous` ∊ {`false`, `true`, _`undef`_}


#### `mc_nice_rotating_dash`

* If this option is enabled,
  the midnight commander shows a rotating dash in the upper right corner
  as a work in progress indicator.

* `mc_nice_rotating_dash` ∊ {`false`, `true`, _`undef`_}


#### `mc_cd_symlinks`

* This option, if set, causes the Midnight Commander
  to follow the logical chain of directories
  when changing current directory
  either in the panels, or using the `cd` command.
  This is the default behavior of `bash(1)`.
  When unset, the Midnight Commander follows the real directory structure,
  so `cd ..` provided you've entered that directory through a link
  will move you to the current directory's real parent
  and not to the directory where the link was present.

* `mc_cd_symlinks` ∊ {`false`, `true`, _`undef`_}


#### `mc_safe_delete`

* If this option is enabled,
  deleting files and directory hotlist entries unintentionally
  becomes more difficult.
  The default selection in the confirmation dialogs for deletion
  changes from _Yes_ to _No_.
  This option is disabled by default.

* `mc_safe_delete` ∊ {`false`, `true`, _`undef`_}


#### `mc_auto_save_setup`

* If this option is enabled,
  when you exit the Midnight Commander
  the configurable options of the Midnight Commander
  are saved in the `~/.config/mc/ini` file.

* `mc_auto_save_setup` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_delete`

* Whether deletions have to be confirmed.

* `mc_confirm_delete` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_overwrite`

* Confirm overwrite.

* `mc_confirm_overwrite` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_execute`

* Whether to confirm executions of selected files.

* `mc_confirm_execute` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_exit`

* Whether it is necessary to confirm quitting `mc(1)`.

* `mc_confirm_exit` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_dir_hotlist_del`

* Whether directory hotlist deletion has to be confirmed.

* `mc_confirm_dir_hotlist_del` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_history_cleanup`

* Confirm history cleanup.

* `mc_confirm_history_cleanup` ∊ {`false`, `true`, _`undef`_}


#### `mc_skin`

* The skin name. See also `mc(1)`.

* `mc_skin ~= /^.*$/` +
  `mc_skin` = _`undef`_


#### `mc_use_8th_bit_as_meta`

* Full 8bits input.

* `mc_use_8th_bit_as_meta` ∊ {`false`, `true`, _`undef`_}


#### `mc_vfs_timeout`

* Timeout for freeing VFSs (sec).

* `mc_vfs_timeout` ∊ ℤ ∪ {_`undef`_}


#### `mc_ftpfs_directory_timeout`

* FTP directory cache timeout (sec)

* `mc_ftpfs_directory_timeout` ∊ ℤ ∪ {_`undef`_}


#### `mc_ftpfs_always_use_proxy`

* Whether to always use an FTP proxy.

* `mc_ftpfs_always_use_proxy` ∊ {`false`, `true`, _`undef`_}


#### `mc_use_netrc`

* Use `~/.netrc` (see `netrc(5)`).

* `mc_use_netrc` ∊ {`false`, `true`, _`undef`_}


#### `mc_ftpfs_use_pasconex`

* Enables using FTP passive mode,
  when the connection for data transfer is initiated by the client,
  not by the server.
  This option is recommended and enabled by default.
  If this option is turned off,
  the data connection is initiated by the server.
  This may not work with some firewalls.

* `mc_ftpfs_use_pasconex` ∊ {`false`, `true`, _`undef`_}


#### `mc_ftpfs_use_pasconex_x_proxy`

* Use passive mode over proxy.

* `mc_ftpfs_use_pasconex_x_proxy` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_option_auto_par_fmt`

* Wrap mode: Dynamic paragraphing.

* `mc_editor_option_auto_par_fmt` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_option_typewr_wrap`

* Wrap mode: type writer wrap.

* `mc_editor_option_typewr_wrap` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_fake_half_tabs`

* Fake half tabs.

* `mc_editor_fake_half_tabs` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_backspc_throu_tabs`

* Backspace through tabs.

* `mc_editor_backspc_throu_tabs` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_fill_tabs_w_spaces`

* Fill tabs with spaces.

* `mc_editor_fill_tabs_w_spaces` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_tab_spacing`

* Tab spacing width.

* `mc_editor_tab_spacing` ∊ ℤ ∪ {_`undef`_}


#### `mc_editor_return_d_auto_indnt`

* Return does autoindent.

* `mc_editor_return_d_auto_indnt` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_edit_confirm_save`

* Confirm before saving.

* `mc_editor_edit_confirm_save` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_option_sav_position`

* Save file position.

* `mc_editor_option_sav_position` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_visible_spaces`

* Visible trailing spaces.

* `mc_editor_visible_spaces` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_visible_tabs`

* Visible tabs.

* `mc_editor_visible_tabs` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_syntax_highlighting`

* Enable syntax highlighting.

* `mc_editor_syntax_highlighting` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_cursr_after_ins_blk`

* Place the cursor after inserted block.

* `mc_editor_cursr_after_ins_blk` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_persistnt_selexions`

* Persistent selections.

* `mc_editor_persistnt_selexions` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_cursor_beyond_eol`

* Cursor can go beyond end of line.

* `mc_editor_cursor_beyond_eol` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_group_undo`

* Group undo.

* `mc_editor_group_undo` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_word_wrap_ln_length`

* Word wrap line length.

* `mc_editor_word_wrap_ln_length` ∊ ℤ ∪ {_`undef`_}


#### `mc_editor_option_sav_mode`

* Valid save modes are `'quick_save'`, `'safe_save'` and
  `'do_backups_with_extension'`.

* `mc_editor_option_sav_mode` ∊ {`'quick_save'`, `'safe_save'`,
  `'do_backups_with_extension'`, _`undef`_}


#### `mc_editor_backup_extension`

* Only has an effect if
  [`mc_editor_option_sav_mode`](#mc_editor_option_sav_mode)` = 'do_backups_with_extension'`.

* `mc_editor_backup_extension ~= /^.*$/` +
  `mc_editor_backup_extension` = _`undef`_


#### `mc_editor_check_new_line`

* Check POSIX new line.

* `mc_editor_check_new_line` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_line_state`

* See `mcedit(1)`.

* `mc_editor_line_state` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_stop_format_chars`

* Compare `mcedit(1)`.

* `Optional[Array[Pattern[/^.$/], 1]] $mc_editor_stop_format_char = `_`undef`_


#### `mc_editor_wrdcompl_coll_ent_f`

* Search autocomplete candidates in entire of file
  or just from begin of file to cursor position (0).

* `mc_editor_wrdcompl_coll_ent_f` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_simple_statusbar`

* Whether to use a simple statusbar or not.

* `mc_editor_simple_statusbar` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_show_right_margin`

* Whether to show a right margin
  by inverting foreground and background colors beyond it.

* `mc_editor_show_right_margin` ∊ {`false`, `true`, _`undef`_}


#### `mc_editor_filesize_threshold`

* Maximum filesize the editor is willing to edit.

* It's a string, so you're able to use unit prefixes.

* `mc_editor_filesize_threshold ~= /^.*$/` +
  `mc_editor_filesize_threshold` = _`undef`_


#### `mc_mcview_eof`

* Displayed string to mark EOF in `mcview(1)`.

* `mc_mcview_eof ~= /^.*$/` + `mc_mcview_eof` = _`undef`_


#### `mc_mcview_remember_file_pos`

* Probably does what it says.

* `mc_mcview_remember_file_pos` ∊ {`false`, `true`, _`undef`_}


#### `mc_max_dirt_limit`

* See `mc(1)` for an explanation.

* `mc_max_dirt_limit` ∊ ℤ ∪ {_`undef`_}


#### `mc_mouse_move_page_viewer`

* See `mc(1)` for an explanation.

* `mc_mouse_move_page_viewer` ∊ {`false`, `true`, _`undef`_}


#### `mc_only_leading_plus_minus`

* See `mc(1)` for an explanation.

* `mc_only_leading_plus_minus` ∊ {`false`, `true`, _`undef`_}


#### `mc_show_output_starts_shell`

* See `mc(1)` for an explanation.

* `mc_show_output_starts_shell` ∊ {`false`, `true`, _`undef`_}


#### `mc_use_file_to_guess_type`

* See `mc(1)` for an explanation.

* `mc_use_file_to_guess_type` ∊ {`false`, `true`, _`undef`_}


#### `mc_xtree_mode`

* See `mc(1)` for an explanation.

* `mc_xtree_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_fish_directory_timeout`

* See `mc(1)` for an explanation.

* `mc_fish_directory_timeout` ∊ ℤ ∪ {_`undef`_}


#### `mc_mouse_close_dialog`

* Undocumented (by `mc(1)`).

* `mc_mouse_close_dialog` ∊ {`false`, `true`, _`undef`_}


#### `mc_mouse_repeat_rate`

* Undocumented (by `mc(1)`).

* `mc_mouse_repeat_rate` ∊ ℤ ∪ {_`undef`_}


#### `mc_double_click_speed`

* Undocumented (by `mc(1)`).

* `mc_double_click_speed` ∊ ℤ ∪ {_`undef`_}


#### `mc_ftpfs_retry_seconds`

* Some limit.

* `mc_ftpfs_retry_seconds` ∊ ℤ ∪ {_`undef`_}


#### `mc_ftpfs_use_unix_lst_option`

* Whether to use UNIX list options.

* `mc_ftpfs_use_unix_lst_option` ∊ {`false`, `true`, _`undef`_}


#### `mc_ftpfs_first_cd_then_ls`

* Whether to do `ls` after `cd`.

* `mc_ftpfs_first_cd_then_ls` ∊ {`false`, `true`, _`undef`_}


#### `mc_ignore_ftp_chattr_errors`

* Whether to ignore `chattr(1)` errors.

* `mc_ignore_ftp_chattr_errors` ∊ {`false`, `true`, _`undef`_}


#### `mc_keymap`

* The name of the keymap to use.

* `mc_keymap ~= /^.*$/` + `mc_keymap` = _`undef`_


#### `mc_alternate_plus_minus`

* Whether to alternate plus and minus.

* `mc_alternate_plus_minus` ∊ {`false`, `true`, _`undef`_}


#### `mc_confirm_view_dir`

* Whether it's necessary to confirm viewing a directory?

* `mc_confirm_view_dir` ∊ {`false`, `true`, _`undef`_}


#### `mc_clear_before_exec`

* Whether to `clear(1)` before executing the selected file.

* `mc_clear_before_exec` ∊ {`false`, `true`, _`undef`_}


#### `mc_wrap_mode`

* Whether wrap mode is enabled.

* `mc_wrap_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_fast_refresh`

* Whether to make fast `refresh(3ncurses)`es.

* `mc_fast_refresh` ∊ {`false`, `true`, _`undef`_}


#### `mc_num_history_items_recorded`

* The maximum number of items the history records.

* `mc_num_history_items_recorded` ∊ ℤ ∪ {_`undef`_}


#### `mc_select_flags`

* ???

* `mc_select_flags` ∊ ℤ ∪ {_`undef`_}


#### `mc_copymove_persistent_attr`

* Whether to enforce `chattr(1)`/`attr(5)` attributes get copymoved, too.
  If setting attributes failed, the whole copy-move fails.

* `mc_copymove_persistent_attr` ∊ {`false`, `true`, _`undef`_}

#### `mc_horizontal_split`

* Whether to horizontal split, thus dividing the screen into a top and bottom panel.

* `mc_horizontal_split` ∊ {`false`, `true`, _`undef`_}


#### `mc_kilobyte_si`

* Whether to use
  [SI-prefixes](https://secure.wikimedia.org/wikipedia/en/wiki/Metric_prefix)
  kilo- and Mega- instead of
  ki[bi-](https://secure.wikimedia.org/wikipedia/en/wiki/Binary_prefix) and Mebi-.

* `mc_kilobyte_si` ∊ {`false`, `true`, _`undef`_}


#### `mc_mix_all_files`

* Disable showing all directories alphabetically first and then normal files.

* `mc_mix_all_files` ∊ {`false`, `true`, _`undef`_}


#### `mc_show_backups`

* Whether to list backup files with the known
  [`mc_editor_backup_extension`](#mc_editor_backup_extension).

* `mc_show_backups` ∊ {`false`, `true`, _`undef`_}


#### `mc_show_dot_files`

* Whether to list files whose filenames start with a `.` (dot).

* `mc_show_dot_files` ∊ {`false`, `true`, _`undef`_}


#### `mc_fast_reload`

* Do fast reload.

* `mc_fast_reload` ∊ {`false`, `true`, _`undef`_}


#### `mc_fast_reload_msg_shown`

* Whether the message of using fast reload was shown.
  The user's own configuration is supposed to overwrite this value,
  once it was displayed for him/her.

* `mc_fast_reload_msg_shown` ∊ {`false`, `true`, _`undef`_}


#### `mc_mark_moves_down`

* Whether marking a file also moves the cursor down.

* `mc_mark_moves_down` ∊ {`false`, `true`, _`undef`_}


#### `mc_reverse_files_only`

* Reverse files only.

* `mc_reverse_files_only` ∊ {`false`, `true`, _`undef`_}


#### `mc_auto_save_setup_panels`

* Enables automatically saving the panels setup.

* `mc_auto_save_setup_panels` ∊ {`false`, `true`, _`undef`_}


#### `mc_navigate_with_arrows`

* Allows navigation with arrows.

* `mc_navigate_with_arrows` ∊ {`false`, `true`, _`undef`_}


#### `mc_mouse_moves_pages`

* Whether the rat can move pages, too.

* `mc_mouse_moves_pages` ∊ {`false`, `true`, _`undef`_}


#### `mc_mouse_moves_pages_viewer`

* Whether the rat can move pages in the viewer, too.

* `mc_mouse_moves_pages_viewer` ∊ {`false`, `true`, _`undef`_}


#### `mc_panel_scroll_pages`

* Scroll pages in panels.

* `mc_panel_scroll_pages` ∊ {`false`, `true`, _`undef`_}


#### `mc_torben_fj_mode`

* Switches into `torben_fj_mode`.

* `mc_torben_fj_mod` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_horizontal_split`

* Whether to split into top and bottom parts.

* `mc_layout_horizontal_split` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_equal_split`

* By default, panels have equal sizes.

* `mc_layout_equal_split` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_first_panel_size`

* ???

* `mc_layout_first_panel_size` ∊ ℤ ∪ {_`undef`_}


#### `mc_layout_horizontal_equal`

* Do equally split between top and bottom panels.

* `mc_layout_horizontal_equal` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_top_panel_size`

* The height of the top panel,
  if not [`mc_layout_horizontal_equal`](#mc_layout_horizontal_equal).

* `mc_layout_top_panel_size` ∊ ℤ ∪ {_`undef`_}


#### `mc_layout_vertical_equal`

* Do equally split between left and right panels.

* `mc_layout_vertical_equal` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_left_panel_size`

* The width of the left panel,
  if not [`mc_layout_vertical_equal`](#mc_layout_vertical_equal).

* `mc_layout_left_panel_size` ∊ ℤ ∪ {_`undef`_}


#### `mc_layout_output_lines`

* On the Linux or FreeBSD console
  you can specify how many lines are shown in the output window.
  This option is available if Midnight Commander runs on native console only.

* `mc_layout_output_lines` ∊ ℤ ∪ {_`undef`_}


#### `mc_layout_menubar_visible`

* If enabled,
  the main menu of midnight commander
  is always visible on the top row of screen above panels.
  Enabled by default.

* `mc_layout_menubar_visible` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_command_prompt`

* If enabled, command line is avalable.
  Enabled by default.

* `mc_layout_command_prompt` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_keybar_visible`

* If enabled,
  ten lables associated with `F1`–`F10` keys
  are located at the bottom row of screen.
  Enabled by default.

* `mc_layout_keybar_visible` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_message_visible`

* If enabled, the one-line hints are visible below panels.
  Enabled by default.
  See `/usr/share/mc/hints/mc.hint` for examples.

* `mc_layout_message_visible` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_xterm_title`

* When run in a terminal emulator for X11,
  midnight commander sets the terminal window title
  to the current working directory and updates it when necessary.
  If your terminal emulator is broken
  and you see some incorrect output on startup and directory change,
  turn off this option.
  Enabled by default.

* `mc_layout_xterm_title` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_free_space`

* If enabled, free space and total space of current file system
  is shown at the bottom frame of panel.
  Enabled by default.

* `mc_layout_free_space` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_show_mini_info`

* ???

* `mc_layout_show_mini_info` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_filetype_mode`

* Colorcode filetype mode.

* `mc_layout_filetype_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_layout_permission_mode`

* Colorcode permissions.

* `mc_layout_permission_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_colors_color_terminals`

* List of terminals `mc(1)` always forces color mode with.

* `Type[$mc_colors_color_terminals] = Type[Array[Pattern[/^.*$/], 1]]` +
  `mc_colors_color_terminals` = _`undef`_


#### `mc_panels_show_mini_info`

* If enabled,
  one line of status information about the currently selected item
  is shown at the bottom of the panels.
  Enabled by default.

* `mc_panels_show_mini_info` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_kilobyte_si`

* If this option is enabled,
  midnight commander will use SI units
  (powers of 1000 [a thousand, not eight, you nerd])
  when displaying any byte sizes.
  The suffixes (k, m, …) are shown in lowercase.
  If disabled (default),
  midnight commander will use binary units (powers of 1024)
  and the suffixes are shown in upper case (K, M, …).

* `mc_panels_kilobyte_si` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_mix_all_files`

* If this option is enabled,
  all files and directories are shown mixed together.
  If the option is disabled (default),
  directories (and links to directories)
  are shown at the beginning of the listing,
  and other files below.

* `mc_panels_mix_all_files` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_show_backups`

* If enabled, the midnight commander will show files ending with a tilde.
  Otherwise, they won't be shown (like GNU's `ls(1)` option `-B`).
  Enabled by default.

* `mc_panels_show_backups` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_show_dot_files`

* If enabled,
  the midnight commander will show all files
  that start with a dot (like `ls -a`).
  Disabled by default.

* `mc_panels_show_dot_files` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_fast_reload`

* If this option is enabled,
  the midnight commander will use a trick
  to determine if the directory contents have changed.
  The trick is to reload the directory
  only if the inode of the directory has changed;
  this means that reloads only happen when files are created or deleted.
  If what changes is the inode for a file in the directory
  (file size changes, mode or owner changes, etc.)
  the display is not updated.
  In these cases,
  if you have the option on,
  you have to rescan the directory manually (with `C-r`).
  Disabled by default.

* `mc_panels_fast_reload` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_fast_relod_msg_shwn`

* ???

* `mc_panels_fast_relod_msg_shwn` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_mark_moves_down`

* If enabled,
  the selection bar will move down when you mark a file (with `insert` key).
  Enabled by default.

* `mc_panels_mark_moves_down` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_reverse_files_only`

* Allow revert selection of files only.
  Enabled by default.
  If enabled,
  the reverse selection is applied to files only,
  not to directories.
  The selection of directories is untouched.
  If off, the reverse selection is applied to files as well to directories:
  all unselected items become selected, and vice versa.

* `mc_panels_reverse_files_only` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_simple_swap`

* If both panels contain file listings,
  simple swap means
  that panels exchange their screen positions:
  the left panel becomes the right one, and vice versa.
  If this option is unchecked,
  file listing panels exchange their content
  keeping listing format and sort options.
  Unchecked by default.

* `mc_panels_simple_swap` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_auto_sav_setup_pnls`

* If this option is enabled,
  when you exit the midnight commander
  the current settings of panels are saved in the `~/.config/mc/panels.ini` file.
  Disabled by default.

* `mc_panels_auto_sav_setup_pnls` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_navigate_w_arrows`

* If this option is enabled,
  you may use the arrows keys
  to automatically chdir
  if the current selection is a subdirectory
  and the shell command line is empty.
  By default, this setting is off.

* `mc_panels_navigate_w_arrows` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_panel_scroll_pages`

* If set (the default), panel will scroll by half the display
  when the cursor reaches the end or the beginning of the panel,
  otherwise it will just scroll a file at a time.

* `mc_panels_panel_scroll_pages` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_mouse_move_pages`

* Controls whenever scrolling with the mouse wheel
  is done by pages or line by line on the panels.

* `mc_panels_mouse_move_pages` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_torben_fj_mode`

* See `mc(1)`.

* `mc_panels_torben_fj_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_filetype_mode`

* If the file type highlighting is enabled,
  file names are colored according to rules
  described in `/etc/mc/filehighlight.ini` file.

* `mc_panels_filetype_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_permission_mode`

* You can specify
  whether permissions and file types
  should be highlighted with distinctive colors.
  If the permission highlighting is enabled,
  the parts of the perm and mode display fields
  which apply to the user running midnight commander
  are highlighted with the color defined by the selected keyword.

* `mc_panels_permission_mode` ∊ {`false`, `true`, _`undef`_}


#### `mc_panels_quick_search_mode`

* You can specify how the quick search mode should work:
  `case_insensitive`ly, `case_sensitive`ly or
  be matched to the the panel sort order (`use_panel_sort_mode`):
  case sensitive or not.

* `mc_panels_quick_search_mode` ∊ {`'case_insensitive'`, `'case_sensitive'`,
  `'use_panel_sort_mode'`, _`undef`_}


#### `mc_misc_display_codepage`

* Display code page.

* `mc_misc_display_codepage ~= /^.*$/` +
  `mc_misc_display_codepage` = _`undef`_


#### `mc_misc_ftpfs_password`

* FTP FS password.

* `mc_misc_ftpfs_password ~= /^.*$/` +
  `mc_misc_ftpfs_password` = _`undef`_


#### `mc_misc_ftp_proxy_host`

* Hostname of FTP proxy.

* `mc_misc_ftp_proxy_host ~= /^.*$/` +
  `mc_misc_ftp_proxy_host` = _`undef`_


#### `mc_misc_timeformat_recent`

* Compare `mc(1)`.

* `mc_misc_timeformat_recent ~= /^.*$/` +
  `mc_misc_timeformat_recent` = _`undef`_


#### `mc_misc_timeformat_old`

* Compare `mc(1)`.

* `mc_misc_timeformat_old ~= /^.*$/` +
  `mc_misc_timeformat_old` = _`undef`_


#### `mc_misc_clipboard_store`

* Compare `mc(1)`.

* `mc_misc_clipboard_store ~= /^.*$/` +
  `mc_misc_clipboard_store` = _`undef`_


#### `mc_misc_clipboard_paste`

* Compare `mc(1)`

* `mc_misc_clipboard_paste ~= /^.*$/` +
  `mc_misc_clipboard_paste` = _`undef`_


#### `mc_misc_autodetect_codeset`

* Compare `mc(1)`

* `mc_misc_autodetect_codeset ~= /^.*$/` +
  `mc_misc_autodetect_codeset` = _`undef`_


#### `mc_misc_spell_language`

* ???

* `mc_misc_spell_language ~= /^.*$/` +
  `mc_misc_spell_language` = _`undef`_


#### `mc_misc_source_codepage`

* ???

* `mc_misc_autodetect_codeset ~= /^.*$/` +
  `mc_misc_autodetect_codeset` = _`undef`_


[//]: # ( #### `mc_misc_find_ignore_dirs` )
[//]: # ( ??? )


## Limitations

* This module's been used with stable Debian and Ubuntu releases.
* It can't uninstall `mc` or its changes.
* `/etc/mc/mc.ini` gets _completly_ copied to `~/.config/mc/ini`
  the user invokes `mc` the first time
  (if `~/.config/mc/ini` is absent, to be precise).
  Subsequent changes in `/etc/mc/mc.ini`
  won't be considered automatically.
  Symlinks are resolved _before_ copying
  (→ file contents get copied, not the file itself).


## Development

[//]: # (TODO:)
[//]: # (The release source distributed on PuppetForge is normalized)
[//]: # (in order to gain quality score.)
[//]: # (Don't work with it.)
Drop me a line (`patch(1)`)
`Kai Burghardt <wiz?KaiBurghardt.de>`
(GnuPG usage advised).
This module's primarily targeted for
[already packaged stable open source Puppet](https://docs.puppet.com/guides/puppetlabs_package_repositories.html)
 versions.


## Index

### alphabetical list of all class parameters

* [`distribute_global_mc_ini`](#distribute_global_mc_ini)
* [`etc_mc_skins_default_group`](#etc_mc_skins_default_group)
* [`etc_mc_skins_default_owner`](#etc_mc_skins_default_owner)
* [`etc_mc_skins_default_path`](#etc_mc_skins_default_path)
* [`etc_mc_skins_default_symlink`](#etc_mc_skins_default_symlink)
* [`etc_mc_skins_group`](#etc_mc_skins_group)
* [`etc_mc_skins_mode`](#etc_mc_skins_mode)
* [`etc_mc_skins_owner`](#etc_mc_skins_owner)
* [`etc_mc_skins_path`](#etc_mc_skins_path)
* [`latest_instead_of_present`](#latest_instead_of_present)
* [`mc_alternate_plus_minus`](#mc_alternate_plus_minus)
* [`mc_auto_fill_mkdir_name`](#mc_auto_fill_mkdir_name)
* [`mc_auto_menu`](#mc_auto_menu)
* [`mc_auto_save_setup`](#mc_auto_save_setup)
* [`mc_auto_save_setup_panels`](#mc_auto_save_setup_panels)
* [`mc_cd_symlinks`](#mc_cd_symlinks)
* [`mc_classic_progressbar`](#mc_classic_progressbar)
* [`mc_clear_before_exec`](#mc_clear_before_exec)
* [`mc_colors_color_terminals`](#mc_colors_color_terminals)
* [`mc_confirm_delete`](#mc_confirm_delete)
* [`mc_confirm_dir_hotlist_del`](#mc_confirm_dir_hotlist_del)
* [`mc_confirm_execute`](#mc_confirm_execute)
* [`mc_confirm_exit`](#mc_confirm_exit)
* [`mc_confirm_history_cleanup`](#mc_confirm_history_cleanup)
* [`mc_confirm_overwrite`](#mc_confirm_overwrite)
* [`mc_confirm_view_dir`](#mc_confirm_view_dir)
* [`mc_copymove_persistent_attr`](#mc_copymove_persistent_attr)
* [`mc_double_click_speed`](#mc_double_click_speed)
* [`mc_drop_menus`](#mc_drop_menus)
* [`mc_editor_ask_filename_b_edit`](#mc_editor_ask_filename_b_edit)
* [`mc_editor_backspc_throu_tabs`](#mc_editor_backspc_throu_tabs)
* [`mc_editor_backup_extension`](#mc_editor_backup_extension)
* [`mc_editor_check_new_line`](#mc_editor_check_new_line)
* [`mc_editor_cursor_beyond_eol`](#mc_editor_cursor_beyond_eol)
* [`mc_editor_cursr_after_ins_blk`](#mc_editor_cursr_after_ins_blk)
* [`mc_editor_edit_confirm_save`](#mc_editor_edit_confirm_save)
* [`mc_editor_fake_half_tabs`](#mc_editor_fake_half_tabs)
* [`mc_editor_filesize_threshold`](#mc_editor_filesize_threshold)
* [`mc_editor_fill_tabs_w_spaces`](#mc_editor_fill_tabs_w_spaces)
* [`mc_editor_group_undo`](#mc_editor_group_undo)
* [`mc_editor_line_state`](#mc_editor_line_state)
* [`mc_editor_option_auto_par_fmt`](#mc_editor_option_auto_par_fmt)
* [`mc_editor_option_sav_mode`](#mc_editor_option_sav_mode)
* [`mc_editor_option_sav_position`](#mc_editor_option_sav_position)
* [`mc_editor_option_typewr_wrap`](#mc_editor_option_typewr_wrap)
* [`mc_editor_persistnt_selexions`](#mc_editor_persistnt_selexions)
* [`mc_editor_return_d_auto_indnt`](#mc_editor_return_d_auto_indnt)
* [`mc_editor_show_right_margin`](#mc_editor_show_right_margin)
* [`mc_editor_simple_statusbar`](#mc_editor_simple_statusbar)
* [`mc_editor_stop_format_chars`](#mc_editor_stop_format_chars)
* [`mc_editor_syntax_highlighting`](#mc_editor_syntax_highlighting)
* [`mc_editor_tab_spacing`](#mc_editor_tab_spacing)
* [`mc_editor_visible_spaces`](#mc_editor_visible_spaces)
* [`mc_editor_visible_tabs`](#mc_editor_visible_tabs)
* [`mc_editor_word_wrap_ln_length`](#mc_editor_word_wrap_ln_length)
* [`mc_editor_wrdcompl_coll_ent_f`](#mc_editor_wrdcompl_coll_ent_f)
* [`mc_fast_refresh`](#mc_fast_refresh)
* [`mc_fast_reload`](#mc_fast_reload)
* [`mc_fast_reload_msg_shown`](#mc_fast_reload_msg_shown)
* [`mc_file_op_compute_totals`](#mc_file_op_compute_totals)
* [`mc_fish_directory_timeout`](#mc_fish_directory_timeout)
* [`mc_ftpfs_always_use_proxy`](#mc_ftpfs_always_use_proxy)
* [`mc_ftpfs_directory_timeout`](#mc_ftpfs_directory_timeout)
* [`mc_ftpfs_first_cd_then_ls`](#mc_ftpfs_first_cd_then_ls)
* [`mc_ftpfs_retry_seconds`](#mc_ftpfs_retry_seconds)
* [`mc_ftpfs_use_pasconex`](#mc_ftpfs_use_pasconex)
* [`mc_ftpfs_use_pasconex_x_proxy`](#mc_ftpfs_use_pasconex_x_proxy)
* [`mc_ftpfs_use_unix_lst_option`](#mc_ftpfs_use_unix_lst_option)
* [`mc_horizontal_split`](#mc_horizontal_split)
* [`mc_ignore_ftp_chattr_errors`](#mc_ignore_ftp_chattr_errors)
* [`mc_ini_auth`](#mc_ini_auth)
* [`mc_ini_group`](#mc_ini_group)
* [`mc_ini_mode`](#mc_ini_mode)
* [`mc_ini_owner`](#mc_ini_owner)
* [`mc_ini_path`](#mc_ini_path)
* [`mc_ini_template`](#mc_ini_template)
* [`mc_keymap`](#mc_keymap)
* [`mc_kilobyte_si`](#mc_kilobyte_si)
* [`mc_layout_command_prompt`](#mc_layout_command_prompt)
* [`mc_layout_equal_split`](#mc_layout_equal_split)
* [`mc_layout_filetype_mode`](#mc_layout_filetype_mode)
* [`mc_layout_first_panel_size`](#mc_layout_first_panel_size)
* [`mc_layout_free_space`](#mc_layout_free_space)
* [`mc_layout_horizontal_equal`](#mc_layout_horizontal_equal)
* [`mc_layout_horizontal_split`](#mc_layout_horizontal_split)
* [`mc_layout_keybar_visible`](#mc_layout_keybar_visible)
* [`mc_layout_left_panel_size`](#mc_layout_left_panel_size)
* [`mc_layout_menubar_visible`](#mc_layout_menubar_visible)
* [`mc_layout_message_visible`](#mc_layout_message_visible)
* [`mc_layout_output_lines`](#mc_layout_output_lines)
* [`mc_layout_permission_mode`](#mc_layout_permission_mode)
* [`mc_layout_show_mini_info`](#mc_layout_show_mini_info)
* [`mc_layout_top_panel_size`](#mc_layout_top_panel_size)
* [`mc_layout_vertical_equal`](#mc_layout_vertical_equal)
* [`mc_layout_xterm_title`](#mc_layout_xterm_title)
* [`mc_mark_moves_down`](#mc_mark_moves_down)
* [`mc_max_dirt_limit`](#mc_max_dirt_limit)
* [`mc_mcview_eof`](#mc_mcview_eof)
* [`mc_mcview_remember_file_pos`](#mc_mcview_remember_file_pos)
* [`mc_misc_autodetect_codeset`](#mc_misc_autodetect_codeset)
* [`mc_misc_clipboard_paste`](#mc_misc_clipboard_paste)
* [`mc_misc_clipboard_store`](#mc_misc_clipboard_store)
* [`mc_misc_display_codepage`](#mc_misc_display_codepage)
* [`mc_misc_ftpfs_password`](#mc_misc_ftpfs_password)
* [`mc_misc_ftp_proxy_host`](#mc_misc_ftp_proxy_host)
* [`mc_misc_source_codepage`](#mc_misc_source_codepage)
* [`mc_misc_spell_language`](#mc_misc_spell_language)
* [`mc_misc_timeformat_old`](#mc_misc_timeformat_old)
* [`mc_misc_timeformat_recent`](#mc_misc_timeformat_recent)
* [`mc_mix_all_files`](#mc_mix_all_files)
* [`mc_mouse_close_dialog`](#mc_mouse_close_dialog)
* [`mc_mouse_move_page_viewer`](#mc_mouse_move_page_viewer)
* [`mc_mouse_moves_pages`](#mc_mouse_moves_pages)
* [`mc_mouse_moves_pages_viewer`](#mc_mouse_moves_pages_viewer)
* [`mc_mouse_repeat_rate`](#mc_mouse_repeat_rate)
* [`mc_navigate_with_arrows`](#mc_navigate_with_arrows)
* [`mc_nice_rotating_dash`](#mc_nice_rotating_dash)
* [`mc_num_history_items_recorded`](#mc_num_history_items_recorded)
* [`mc_old_esc_mode`](#mc_old_esc_mode)
* [`mc_old_esc_mode_timeout`](#mc_old_esc_mode_timeout)
* [`mc_only_leading_plus_minus`](#mc_only_leading_plus_minus)
* [`mc_package_name`](#mc_package_name)
* [`mc_panels_auto_sav_setup_pnls`](#mc_panels_auto_sav_setup_pnls)
* [`mc_panel_scroll_pages`](#mc_panel_scroll_pages)
* [`mc_panels_fast_reload`](#mc_panels_fast_reload)
* [`mc_panels_fast_relod_msg_shwn`](#mc_panels_fast_relod_msg_shwn)
* [`mc_panels_filetype_mode`](#mc_panels_filetype_mode)
* [`mc_panels_kilobyte_si`](#mc_panels_kilobyte_si)
* [`mc_panels_mark_moves_down`](#mc_panels_mark_moves_down)
* [`mc_panels_mix_all_files`](#mc_panels_mix_all_files)
* [`mc_panels_mouse_move_pages`](#mc_panels_mouse_move_pages)
* [`mc_panels_navigate_w_arrows`](#mc_panels_navigate_w_arrows)
* [`mc_panels_panel_scroll_pages`](#mc_panels_panel_scroll_pages)
* [`mc_panels_permission_mode`](#mc_panels_permission_mode)
* [`mc_panels_quick_search_mode`](#mc_panels_quick_search_mode)
* [`mc_panels_reverse_files_only`](#mc_panels_reverse_files_only)
* [`mc_panels_show_backups`](#mc_panels_show_backups)
* [`mc_panels_show_dot_files`](#mc_panels_show_dot_files)
* [`mc_panels_show_mini_info`](#mc_panels_show_mini_info)
* [`mc_panels_simple_swap`](#mc_panels_simple_swap)
* [`mc_panels_torben_fj_mode`](#mc_panels_torben_fj_mode)
* [`mc_pause_after_run`](#mc_pause_after_run)
* [`mc_preallocate_space`](#mc_preallocate_space)
* [`mc_reverse_files_only`](#mc_reverse_files_only)
* [`mc_safe_delete`](#mc_safe_delete)
* [`mc_select_flags`](#mc_select_flags)
* [`mc_shell_patterns`](#mc_shell_patterns)
* [`mc_show_all_if_ambiguous`](#mc_show_all_if_ambiguous)
* [`mc_show_backups`](#mc_show_backups)
* [`mc_show_dot_files`](#mc_show_dot_files)
* [`mc_show_output_starts_shell`](#mc_show_output_starts_shell)
* [`mc_skin`](#mc_skin)
* [`mc_torben_fj_mode`](#mc_torben_fj_mode)
* [`mc_use_8th_bit_as_meta`](#mc_use_8th_bit_as_meta)
* [`mc_use_file_to_guess_type`](#mc_use_file_to_guess_type)
* [`mc_use_internal_edit`](#mc_use_internal_edit)
* [`mc_use_internal_view`](#mc_use_internal_view)
* [`mc_use_netrc`](#mc_use_netrc)
* [`mc_verbose`](#mc_verbose)
* [`mc_vfs_timeout`](#mc_vfs_timeout)
* [`mc_wrap_mode`](#mc_wrap_mode)
* [`mc_xtree_mode`](#mc_xtree_mode)



---

Authors of this `readme.md` → see source code (of `readme.md` itself).

[//]: # ( this file should be saved in enc=utf8 )
[//]: # ( vim: set ft=markdown tw=80 ts=4 noet bs=eol,start,indent: )
